@@ -25,6 +25,8 @@ utils::globalVariables(
     "Place",
     "Points",
     "Row_Numb",
+    "Row_Numb_Adjusted",
+    "relay_swimmers",
     "Event",
     "read_html",
     ":=",
@@ -53,6 +55,7 @@ utils::globalVariables(
     "Finals_Place",
     "DQ",
     "Heat",
+    "Heat_Row_Min",
     "Exhibition",
     "Time",
     "Lane",
